==> humhub-1.8.0-beta.1.tar.gz: humhub-1.8.0-beta.1/protected/humhub/modules/content/messages/nl/base.php <==
<?php
return array (
  '(Also visible to non-members of this space)' => '(Ook zichtbaar voor niet-leden van deze ruimte)',
  '<strong>Confirm</strong> post deletion' => '<strong>Bevestig</strong> bericht verwijderen',
  '<strong>Move</strong> content' => 'Inhoud <strong>verplaatsen</strong>',
  '<strong>Permalink</strong> to this post' => '<strong>Permalink</strong> naar dit bericht',
  'Add a member to notify' => 'Hou een lid op de hoogte',
  'Archived' => 'Gearchiveerd',
  'Attach Files' => 'Voeg bestanden toe',
  'Back to stream' => 'Terug naar berichten',
  'Cancel' => 'Annuleren',
  'Cancel Edit' => 'Annuleer bewerking',
  'Content' => 'Inhoud',
  'Content Tag with invalid contentcontainer_id assigned.' => 'Content Tag met ongeldige contentcontainer_id toegewezen.',
  'Content has been moved to {spacename}' => 'De inhoud is verplaatst naar {spacename}',
  'Content visibility' => 'Inhoud zichtbaar',
  'Could not delete content!' => 'Kan de inhoud niet verwijderen!',
  'Could not delete content: Access denied!' => 'Kan de inhoud niet verwijderen: toegang verwijderd!',
  'Could not find requested content!' => 'Kon de gevraagde inhoud niet vinden!',
  'Created by me' => 'Aangemaakt door mij',
  'Creation time' => 'Aanmaak datum',
  'Delete' => 'Verwijder',
  'Do you really want to delete this post? All likes and comments will be lost!' => 'Weet u zeker dat u dit bericht wilt verwijderen? Alle vind-ik-leuks en reacties zullen verloren gaan!',
  'Edit' => 'Bewerk',
  'Filter' => 'Filter',
  'Invalid content id given!' => 'Content ID is ongeldig!',
  'Invalid request method!' => 'Ongeldige aanroep!',
  'Invalid space selection.' => 'Ongeldige ruimteselectie.',
  'Last update' => 'Laatste bijwerk datum',
  'Last updated {time}' => 'Laatst bijgewerkt {time}',
  'Load more' => 'Meer laden',
  'Change to "Private"' => 'Maak privé',
  'Change to "Public"' => 'Maak publiek',
  'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'Het maximaal aantal vastgezette items bereikt! <br /> U kunt maximaal {count} items tegelijk vastzetten.',
  'Move content' => 'Verplaats inhoud',
  'Move to archive' => 'Verplaats naar archief',
  'No matches with your selected filters!' => 'Geen resultaten met de geselecteerde filters!',
  'None' => 'Geen',
  'Nothing here yet!' => 'Nog niets om weer te geven!',
  'Notify members' => 'Breng leden op de hoogte',
  'Only private content' => 'Alleen privé inhoud',
  'Only public content' => 'Alleen openbare inhoud',
  'Permalink' => 'Permalink',
  'Pin to top' => 'Kleef vast',
  'Pinned' => 'Vastgekleefd',
  'Public' => 'Publiek',
  'Specify who can see this content.' => 'Geef op wie deze inhoud mag zien.',
  'Submit' => 'Verzenden',
  'Tag' => 'Label',
  'Target Space' => 'Nieuwe ruimte',
  'The author of this content is not allowed to create private content within the selected space.' => 'De auteur van deze inhoud mag geen privé-inhoud maken binnen de geselecteerde ruimte.',
  'The author of this content is not allowed to create public content within the selected space.' => 'De auteur van deze inhoud mag geen openbare-inhoud maken binnen de geselecteerde ruimte.',
  'The author of this content is not allowed to create this type of content within this space.' => 'De auteur mag dit type inhoud in deze ruimte niet maken.',
  'The content can\'t be moved to its current space.' => 'De inhoud kan niet worden verplaatst naar de huidige ruimte.',
  'The content has been archived.' => 'De inhoud is gearchiveerd.',
  'The content has been deleted.' => 'De inhoud is verwijderd.',
  'The content has been unarchived.' => 'De inhoud is uit het archief gehaald.',
  'The given name is already in use.' => 'De opgegeven naam is al in gebruik.',
  'The module {moduleName} is not enabled on the selected target space.' => 'De module {moduleName} is niet ingeschakeld in de geselecteerde nieuwe ruimte.',
  'This action is disabled!' => 'Deze actie is uitgeschakeld!',
  'This content type can\'t be moved due to a missing module-id setting.' => 'Dit inhoudstype kan niet worden verplaatst vanwege een ontbrekende module-ID-instelling.',
  'This content type can\'t be moved.' => 'Dit inhoudstype kan niet worden verplaatst.',
  'This space is archived.' => 'Deze ruimte is gearchiveerd.',
  'This space is not visible!' => 'Deze ruimte is niet zichtbaar!',
  'Topics' => 'Rubriek',
  'Turn off notifications' => 'Meldingen uitzetten',
  'Turn on notifications' => 'Meldingen aanzetten',
  'Unarchive' => 'Dearchiveer',
  'Unpin' => 'Maak los',
  'Updated' => 'Bijgewerkt',
  'Visible also to unregistered users' => 'Ook zichtbaar voor niet-geregistreerde gebruikers',
  'Visible only to you' => 'Alleen zichtbaar voor jou',
  'Visible to all Space members' => 'Zichtbaar voor alle ruimte-leden',
  'Visible to all signed in users' => 'Zichtbaar voor alle aangemelde gebruikers',
  'Visible to friends of {displayName}' => 'Zichtbaar voor vrienden van {displayName}',
  'Visible to you and {displayName}' => 'Zichtbaar voor u en {displayName}',
  'Visible to your friends' => 'Zichtbaar voor uw vrienden',
  'Where I\'m involved' => 'Waar ik bij betrokken ben',
  'With file attachments' => 'Met bestandsbijlagen',
  'You do not have the permission to move this content to the given space.' => 'U bent niet gemachtigd om deze inhoud naar de opgegeven ruimte te verplaatsen.',
  'You do not have the permission to move this content.' => 'U bent niet gemachtigd om deze inhoud  te verplaatsen.',
  'Your last edit state has been saved!' => 'Uw laatste bewerking is bewaard!',
  'in' => 'in',
);

==> humhub-1.17.0-beta.1.tar.gz: humhub-1.17.0-beta.1/protected/humhub/modules/content/messages/nl/base.php <==
<?php
return array (
  '(Also visible to non-members of this space)' => '(Ook zichtbaar voor niet-leden van deze ruimte)',
  '(Also visible to people who are not logged in)' => '(Ook zichtbaar voor mensen die niet zijn ingelogd)',
  '<strong>Delete</strong> content?' => 'Inhoud <strong>verwijderen</strong>?',
  '<strong>Move</strong> content' => 'Inhoud <strong>verplaatsen</strong>',
  '<strong>Permalink</strong> to this post' => '<strong>Permalink</strong> naar dit bericht',
  '<strong>Scheduling</strong> Options' => '<strong>Planning</strong> opties',
  'Activate scheduling' => 'Activeer de planningmogelijkheden',
  'Add a member to notify' => 'Hou een lid op de hoogte',
  'Add tag...' => 'Label toevoegen...',
  'Advanced Content Search' => 'Geavanceerd zoeken naar inhoud',
  'Archived' => 'Gearchiveerd',
  'Attach Files' => 'Voeg bestanden toe',
  'Back to stream' => 'Terug naar berichten',
  'Cancel' => 'Annuleren',
  'Cancel Edit' => 'Annuleer bewerking',
  'Cannot notify the author.' => 'Kan de auteur niet op de hoogte stellen.',
  'Change to "Private"' => 'Maak privé',
  'Change to "Public"' => 'Maak publiek',
  'Comments are locked' => 'Reacties zijn vergrendeld',
  'Comments are unlocked' => 'Reacties zijn ontgrendeld',
  'Configure' => 'Configureren',
  'Confirm' => 'Bevestig',
  'Content' => 'Inhoud',
  'Content Tag with invalid contentcontainer_id assigned.' => 'Inhjoudsabel met ongeldige contentcontainer_id toegewezen.',
  'Content has been moved to {spacename}' => 'De inhoud is verplaatst naar {spacename}',
  'Could not find requested content!' => 'Kon de gevraagde inhoud niet vinden!',
  'Create as draft' => 'Aanmaken als concept',
  'Created at:' => 'Gemaakt op',
  'Created by me' => 'Aangemaakt door mij',
  'Creation time' => 'Aanmaak datum',
  'Delete' => 'Verwijder',
  'Deleted' => 'Verwijderd',
  'Do you want to delete this content, including all comments and attachments?<br><br>Please note: If a stream entry was created using a module, the original content that this entry is linked to will also be deleted.' => 'Wilt u deze inhoud verwijderen, inclusief alle opmerkingen en bijlagen?<br><br>Let op: als een stream-item is gemaakt met behulp van een module, wordt de originele inhoud waaraan dit item is gekoppeld, ook verwijderd.',
  'Draft' => 'Concept',
  'Edit' => 'Bewerk',
  'Enable' => 'Inschakelen',
  'Enabled' => 'Ingeschakeld',
  'Filter' => 'Filter',
  'Hidden' => 'Verborgen',
  'I\'m involved' => 'Waar ik bij betrokken ben',
  'Invalid content id given!' => 'Content ID is ongeldig!',
  'Invalid request method!' => 'Ongeldige aanroep!',
  'Invalid space selection.' => 'Ongeldige ruimteselectie.',
  'Last update' => 'Laatste bijwerk datum',
  'Last updated {time}' => 'Laatst bijgewerkt {time}',
  'Load more' => 'Meer laden',
  'Lock comments' => 'Reacties vergrendelen',
  'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'Het maximaal aantal vastgezette items bereikt! <br /> U kunt maximaal {count} items tegelijk vastzetten.',
  'Move content' => 'Verplaats inhoud',
  'Move to archive' => 'Verplaats naar archief',
  'New Updates Available!' => 'Nieuwe updates beschikbaar!',
  'No matches with your selected filters!' => 'Geen resultaten met de geselecteerde filters!',
  'No tags found for the given query' => 'Geen labels gevonden voor deze zoekopdracht',
  'None' => 'Geen',
  'Note: Due to technical reasons there may be a delay of a few minutes.' => 'Let op: Om technische redenen kan er een vertraging van enkele minuten optreden.',
  'Nothing here yet!' => 'Nog niets om weer te geven!',
  'Notify members' => 'Breng leden op de hoogte',
  'Permalink' => 'Permalink',
  'Pin to top' => 'Kleef vast',
  'Pinned' => 'Vastgekleefd',
  'Private' => 'Privaat',
  'Public' => 'Publiek',
  'Publish draft' => 'Concept publiceren',
  'Save as draft' => 'Opslaan als concept',
  'Save scheduling' => 'Bewaar planning',
  'Schedule publication' => 'Plan publicatie',
  'Scheduled for {dateTime}' => 'Gepland voor {dateTime}',
  'Select type...' => 'Selecteer type...',
  'Specify who can see this content.' => 'Geef op wie deze inhoud mag zien.',
  'Submit' => 'Verzenden',
  'Tag' => 'Label',
  'Target Space' => 'Nieuwe ruimte',
  'The author of this content is not allowed to create private content within the selected space.' => 'De auteur van deze inhoud mag geen privé-inhoud maken binnen de geselecteerde ruimte.',
  'The author of this content is not allowed to create public content within the selected space.' => 'De auteur van deze inhoud mag geen openbare-inhoud maken binnen de geselecteerde ruimte.',
  'The author of this content is not allowed to create this type of content within this space.' => 'De auteur mag dit type inhoud in deze ruimte niet maken.',
  'The content can\'t be moved to its current space.' => 'De inhoud kan niet worden verplaatst naar de huidige ruimte.',
  'The content cannot be published!' => 'De inhoud kan niet worden gepubliceerd!',
  'The content has been archived.' => 'De inhoud is gearchiveerd.',
  'The content has been deleted.' => 'De inhoud is verwijderd.',
  'The content has been successfully published.' => 'De inhoud is succesvol gepubliceerd.',
  'The content has been unarchived.' => 'De inhoud is uit het archief gehaald.',
  'The given name is already in use.' => 'De opgegeven naam is al in gebruik.',
  'The module {moduleName} is not enabled on the selected target space.' => 'De module {moduleName} is niet ingeschakeld in de geselecteerde nieuwe ruimte.',
  'This action is disabled!' => 'Deze actie is uitgeschakeld!',
  'This content type can\'t be moved due to a missing module-id setting.' => 'Dit inhoudstype kan niet worden verplaatst vanwege een ontbrekende module-ID-instelling.',
  'This content type can\'t be moved.' => 'Dit inhoudstype kan niet worden verplaatst.',
  'This space is archived.' => 'Deze ruimte is gearchiveerd.',
  'This space is not visible!' => 'Deze ruimte is niet zichtbaar!',
  'Topics' => 'Rubriek',
  'Turn off notifications' => 'Meldingen uitzetten',
  'Turn on notifications' => 'Meldingen aanzetten',
  'Unarchive' => 'Dearchiveer',
  'Unlock comments' => 'Reacties ontgrendelen',
  'Unpin' => 'Maak los',
  'Updated' => 'Bijgewerkt',
  'Visible also to unregistered users' => 'Ook zichtbaar voor niet-geregistreerde gebruikers',
  'Visible only to you' => 'Alleen zichtbaar voor jou',
  'Visible to all Space members' => 'Zichtbaar voor alle ruimte-leden',
  'Visible to all signed in users' => 'Zichtbaar voor alle aangemelde gebruikers',
  'Visible to friends of {displayName}' => 'Zichtbaar voor vrienden van {displayName}',
  'Visible to you and {displayName}' => 'Zichtbaar voor u en {displayName}',
  'Visible to your friends' => 'Zichtbaar voor uw vrienden',
  'With attachments' => 'Met bestandsbijlagen',
  'You cannot block the space owner!' => 'U kunt de eigenaar van de ruimte niet blokkeren!',
  'You cannot block the user of the same container!' => 'U kunt de gebruiker van dezelfde container niet blokkeren!',
  'You cannot block yourself!' => 'U kunt uzelf niet blokkeren!',
  'You do not have the permission to move this content to the given space.' => 'U bent niet gemachtigd om deze inhoud naar de opgegeven ruimte te verplaatsen.',
  'You do not have the permission to move this content.' => 'U bent niet gemachtigd om deze inhoud  te verplaatsen.',
  'Your last edit state has been saved!' => 'Uw laatste bewerking is bewaard!',
  'in' => 'in',
);
